==> react-infinite-calendar-2.0.0-rc.4.tgz: package/es/Header/index.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { PureComponent, PropTypes } from 'react';
import ReactCSSTransitionGroup from 'react-addons-css-transition-group';
import classNames from 'classnames';
import format from 'date-fns/format';
var styles = {
  'root': 'Cal__Header__root',
  'blank': 'Cal__Header__blank',
  'wrapper': 'Cal__Header__wrapper',
  'landscape': 'Cal__Header__landscape',
  'dateWrapper': 'Cal__Header__dateWrapper',
  'day': 'Cal__Header__day',
  'active': 'Cal__Header__active',
  'year': 'Cal__Header__year',
  'date': 'Cal__Header__date'
};
var animation = {
  'enter': 'Cal__Animation__enter',
  'enterActive': 'Cal__Animation__enterActive',
  'leave': 'Cal__Animation__leave',
  'leaveActive': 'Cal__Animation__leaveActive'
};

var Header = function (_PureComponent) {
  _inherits(Header, _PureComponent);

  function Header() {
    _classCallCheck(this, Header);

    return _possibleConstructorReturn(this, _PureComponent.apply(this, arguments));
  }

  Header.prototype.render = function render() {
    var _classNames;

    var _props = this.props,
        display = _props.display,
        layout = _props.layout,
        _props$locale = _props.locale,
        blank = _props$locale.blank,
        headerFormat = _props$locale.headerFormat,
        locale = _props$locale.locale,
        scrollToDate = _props.scrollToDate,
        selectedDate = _props.selectedDate,
        setDisplay = _props.setDisplay,
        shouldHeaderAnimate = _props.shouldHeaderAnimate,
        theme = _props.theme;

    var values = selectedDate && [{
      active: display === 'years',
      handleClick: function handleClick(e) {
        e && e.stopPropagation();
        setDisplay('years');
      },
      item: 'year',
      title: display === 'days' ? 'Change year' : null,
      value: selectedDate.getFullYear()
    }, {
      active: display === 'days',
      handleClick: function handleClick(e) {
        e && e.stopPropagation();

        if (display !== 'days') {
          setDisplay('days');
        } else if (selectedDate) {
          scrollToDate(selectedDate, -40);
        }
      },
      item: 'day',
      key: format(selectedDate, 'YYYYMMDD', { locale: locale }),
      title: display === 'days' ? 'Scroll to ' + format(format, headerFormat, { locale: locale }) : null,
      value: format(selectedDate, headerFormat, { locale: locale })
    }];

    return React.createElement(
      'div',
      {
        className: classNames(styles.root, (_classNames = {}, _classNames[styles.blank] = !selectedDate, _classNames[styles.landscape] = layout === 'landscape', _classNames)),
        style: {
          backgroundColor: theme.headerColor,
          color: theme.textColor.active
        }
      },
      selectedDate ? React.createElement(
        'div',
        {
          className: styles.wrapper,
          'aria-label': format(format, headerFormat + ' YYYY', { locale: locale })
        },
        values.map(function (_ref) {
          var _classNames2;

          var handleClick = _ref.handleClick,
              item = _ref.item,
              key = _ref.key,
              value = _ref.value,
              active = _ref.active,
              title = _ref.title;

          return React.createElement(
            'div',
            {
              key: item,
              className: classNames(styles.dateWrapper, styles[item], (_classNames2 = {}, _classNames2[styles.active] = active, _classNames2)),
              title: title
            },
            React.createElement(
              ReactCSSTransitionGroup,
              {
                transitionName: animation,
                transitionEnterTimeout: 250,
                transitionLeaveTimeout: 250,
                transitionEnter: shouldHeaderAnimate,
                transitionLeave: shouldHeaderAnimate
              },
              React.createElement(
                'span',
                {
                  key: item + '-' + (key || value),
                  className: styles.date,
                  'aria-hidden': true,
                  onClick: handleClick
                },
                value
              )
            )
          );
        })
      ) : React.createElement(
        'div',
        { className: styles.wrapper },
        blank
      )
    );
  };

  return Header;
}(PureComponent);

export { Header as default };
process.env.NODE_ENV !== "production" ? Header.propTypes = {
  display: PropTypes.string,
  layout: PropTypes.string,
  locale: PropTypes.object,
  onClick: PropTypes.func,
  selectedDate: PropTypes.oneOfType([PropTypes.instanceOf(Date), PropTypes.bool]),
  shouldHeaderAnimate: PropTypes.bool,
  theme: PropTypes.object
} : void 0;

==> react-infinite-calendar-2.1.5.tgz: package/es/Header/index.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { PureComponent, PropTypes } from 'react';
import { emptyFn } from '../utils';
import defaultSelectionRenderer from './defaultSelectionRenderer';
import classNames from 'classnames';
var styles = {
  'root': 'Cal__Header__root',
  'landscape': 'Cal__Header__landscape',
  'dateWrapper': 'Cal__Header__dateWrapper',
  'day': 'Cal__Header__day',
  'wrapper': 'Cal__Header__wrapper',
  'blank': 'Cal__Header__blank',
  'active': 'Cal__Header__active',
  'year': 'Cal__Header__year',
  'date': 'Cal__Header__date',
  'range': 'Cal__Header__range'
};
var Header = (_temp = _class = function (_PureComponent) {
  _inherits(Header, _PureComponent);

  function Header() {
    _classCallCheck(this, Header);

    return _possibleConstructorReturn(this, _PureComponent.apply(this, arguments));
  }

  Header.prototype.render = function render() {
    var _classNames;

    var _props = this.props,
        layout = _props.layout,
        blank = _props.locale.blank,
        selected = _props.selected,
        renderSelection = _props.renderSelection,
        theme = _props.theme;


    return React.createElement(
      'div',
      {
        className: classNames(styles.root, (_classNames = {}, _classNames[styles.landscape] = layout === 'landscape', _classNames)),
        style: {
          backgroundColor: theme.headerColor,
          color: theme.textColor.active
        }
      },
      selected && renderSelection(selected, this.props) || React.createElement(
        'div',
        { className: classNames(styles.wrapper, styles.blank) },
        blank
      )
    );
  };

  return Header;
}(PureComponent), _class.defaultProps = {
  onYearClick: emptyFn,
  renderSelection: defaultSelectionRenderer
}, _temp);
export { Header as default };
process.env.NODE_ENV !== "production" ? Header.propTypes = {
  dateFormat: PropTypes.string,
  display: PropTypes.string,
  layout: PropTypes.string,
  locale: PropTypes.object,
  onYearClick: PropTypes.func,
  selected: PropTypes.any,
  shouldAnimate: PropTypes.bool,
  theme: PropTypes.object
} : void 0;
